==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/CategoryDateTimeXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisBaseDescriptionMetadata } from "./TimeAxisBaseDescriptionMetadata";
import { CategoryDateTimeXAxisDescription } from "./CategoryDateTimeXAxisDescription";
/**
 * @hidden
 */
var CategoryDateTimeXAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CategoryDateTimeXAxisDescriptionMetadata, _super);
    function CategoryDateTimeXAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryDateTimeXAxisDescriptionMetadata.b = function (a) {
        if (CategoryDateTimeXAxisDescriptionMetadata.a == null) {
            CategoryDateTimeXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryDateTimeXAxisDescriptionMetadata.c(CategoryDateTimeXAxisDescriptionMetadata.a);
        }
        if (a.g(CategoryDateTimeXAxisDescriptionMetadata.a)) {
            return;
        }
        a.s(CategoryDateTimeXAxisDescriptionMetadata.a);
    };
    CategoryDateTimeXAxisDescriptionMetadata.c = function (a) {
        TimeAxisBaseDescriptionMetadata.c(a);
        a.item("DisplayType", "ExportedType:string:TimeAxisDisplayType");
        a.item("DisplayType@names", "Continuous;Discrete");
        a.item("Interval", "Number:long");
        a.item("ActualInterval", "Number:long");
        a.item("MinorInterval", "Number:long");
        a.item("ActualMinorInterval", "Number:long");
        a.item("ActualIntervalChangeRef", "EventRef::actualIntervalChange");
        a.item("ActualMinorIntervalChangeRef", "EventRef::actualMinorIntervalChange");
    };
    CategoryDateTimeXAxisDescriptionMetadata.d = function (a) {
        CategoryDateTimeXAxisDescriptionMetadata.b(a);
        a.u("CategoryDateTimeXAxis", function () { return new CategoryDateTimeXAxisDescription(); });
        a.t("CategoryDateTimeXAxis", CategoryDateTimeXAxisDescriptionMetadata.a);
    };
    CategoryDateTimeXAxisDescriptionMetadata.$t = markType(CategoryDateTimeXAxisDescriptionMetadata, 'CategoryDateTimeXAxisDescriptionMetadata');
    CategoryDateTimeXAxisDescriptionMetadata.a = null;
    return CategoryDateTimeXAxisDescriptionMetadata;
}(Base));
export { CategoryDateTimeXAxisDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/CategoryDateTimeXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisBaseDescriptionMetadata } from "./TimeAxisBaseDescriptionMetadata";
import { CategoryDateTimeXAxisDescription } from "./CategoryDateTimeXAxisDescription";
/**
 * @hidden
 */
var CategoryDateTimeXAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CategoryDateTimeXAxisDescriptionMetadata, _super);
    function CategoryDateTimeXAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryDateTimeXAxisDescriptionMetadata.b = function (a) {
        if (CategoryDateTimeXAxisDescriptionMetadata.a == null) {
            CategoryDateTimeXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryDateTimeXAxisDescriptionMetadata.c(CategoryDateTimeXAxisDescriptionMetadata.a);
        }
        if (a.j(CategoryDateTimeXAxisDescriptionMetadata.a)) {
            return;
        }
        a.y(CategoryDateTimeXAxisDescriptionMetadata.a);
    };
    CategoryDateTimeXAxisDescriptionMetadata.c = function (a) {
        TimeAxisBaseDescriptionMetadata.c(a);
        a.item("DisplayType", "ExportedType:string:TimeAxisDisplayType");
        a.item("DisplayType@names", "Continuous;Discrete");
        a.item("Interval", "Number:long");
        a.item("ActualInterval", "Number:long");
        a.item("MinorInterval", "Number:long");
        a.item("ActualMinorInterval", "Number:long");
        a.item("ActualIntervalChangeRef", "EventRef::actualIntervalChange");
        a.item("ActualMinorIntervalChangeRef", "EventRef::actualMinorIntervalChange");
    };
    CategoryDateTimeXAxisDescriptionMetadata.d = function (a) {
        CategoryDateTimeXAxisDescriptionMetadata.b(a);
        a.aa("CategoryDateTimeXAxis", function () { return new CategoryDateTimeXAxisDescription(); });
        a.z("CategoryDateTimeXAxis", CategoryDateTimeXAxisDescriptionMetadata.a);
    };
    CategoryDateTimeXAxisDescriptionMetadata.$t = markType(CategoryDateTimeXAxisDescriptionMetadata, 'CategoryDateTimeXAxisDescriptionMetadata');
    CategoryDateTimeXAxisDescriptionMetadata.a = null;
    return CategoryDateTimeXAxisDescriptionMetadata;
}(Base));
export { CategoryDateTimeXAxisDescriptionMetadata };
